# Akuvox X912 Control4 Driver
&copy; 2024 uControl, LLC.

For more information, see the [driver website](https://ucontrol.tech/drivers/x912).

## Capabilities and Limitations

This driver will allow you to respond to events on your Akuvox X912 within Control4 Composer.

- In order to receive events from the X912, this driver will modify the settings the X912 uses to send push notifications on events such as login triggers.  Therefore, this driver can not be used if you also use the X912 to send push notifications to other devices outside of the Control4 ecosystem, other than web relays.
- The driver is able to automatically configure the X912 to send the needed notifications when provided with its IP address, username and password.
- This driver will allow you to react to valid and invalid logins in Control4 Composer.  You may also add conditions on the specific user name, or user ID.
- This driver will not detect if the Akuvox X912's settings are changed again after it configures, if the X912 is disconnected, experiences power loss, or its network address changes.

## Setup

### Properties

**IP Address**:  The IP Address of your Akuvox X912.  If you put the IP address after http:// in your web browser, you should see the Akuvox X912 configuraton page.

**HTTP API Username**:  The username as set on your Akuvox X912 "HTTP API" setting.  Authorization mode must be Basic. 

**HTTP API Password**:  The password as set on your Akuvox X912 "HTTP API" setting.  Authorization mode must be Basic.

**X912 Configured**:  "Yes" if the Akuvox X912 has been successfully configured.

**SIP Username**:  The username to set within the Communication Agent's SIP server.  This will be auto-configured for you based on this setting.

**SIP Password**:  The password to set within the Communication Agent's SIP server.  This will be auto-configured for you based on this setting.

**SIP Configured**:  Whether the X912 intercom was successfully configured within the Communication Agent's SIP server.

**SIP Port**:  The port that your Communication Agent's SIP server is listening on. 

**Display Label**:  The display label to show on the Akuvox X912's screen.

**Display Name**:  The display name to show on the Akuvox X912's screen.

**Motion Detection Timeout**:  The number of milliseconds to wait after detecting motion from the X912's camera before closing the Motion Sensor proxy.

### Surveillance

The settings chosen for the X912's camera should be set directly in the Akuvox X912 Camera pane.

### Actions

**Reconfigure X912**:  Press to attempt to reconfigure push notifications on the X912.

**Trigger Relay A**:  Trigger Security Relay A.  Note that this will not override the settings in the X912 configuration UI, so this will not succeed unless the security relay is enabled.

**Trigger Relay B**:  Trigger Security Relay B.  Note that this will not override the settings in the X912 configuration UI, so this will not succeed unless the security relay is enabled.

## Control4 Composer

### Events

**Valid User**:  This event is raised whenever an authorized user authenticates into the Akuvox X912.

**Invalid User**:  This event is raised whenever an unauthorized user attempts to authenticate into the Akuvox X912.

**Relay A Triggered**:  This event is raised whenever Security Relay A is triggered.

**Relay B Triggered**:  This event is raised whenever Security Relay B is triggered.

**Input A Triggered**:  This event is raised whenever Input A is triggered.

**Input B Triggered**:  This event is raised whenever Input B is triggered.

**Input C Triggered**:  This event is raised whenever Input C is triggered.

**Motion Sensor Triggered**:  This event is raised whenever the X912's video motion sensor triggerse.

You may also set up to two custom button events through the Intercom.  These are configured directly in the intercom pane in Director.

These events will look like "'{button name}' UI Button Pressed".

### Variables

You may use these variables in conditions to react to specific users authenticating.

**Last Invalid User ID**:  If known, the User ID of the user that last tried to authenticate.

**Last Invalid User Name**:  If known, the name of the user that last tried to authenticate.

**Last Valid User ID**:  The User ID of the user that last authenticated..

**Last Valid User Name**:  The name of the user that last authenticated.  Since multiple users could have the same name, it is not recommended that you use this in conditionals for sensitive actions.  Instead, you should use Last Valid User ID for sensitive actions.

**Setup Successful**:  Whether the Akuvox X912 was successfully configured by the driver.
